from .middleware import GeneralMiddleware


def apply_middleware(get_request_data, respond_with_error, next_handler):
    middleware = GeneralMiddleware(get_request_data, respond_with_error, next_handler)
    return middleware



# setup.py
from setuptools import setup, find_packages

setup(
    name='my_middleware',
    version='0.17',
    packages=find_packages(),
    install_requires=[
        'Flask>=2.0.0'
    ],
    description='A Flask middleware package to perform pre-checks before request execution.',
    author='Vishwaranjan Kumar',
    author_email='vishwaranjan.kumar@infoobjects.com',
    url='https://github.com/vishwaranjankumar2000/my_middleware',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)



import requests

class GeneralMiddleware:
    def __init__(self, get_request_data, respond_with_error, next_handler):
        self.get_request_data = get_request_data
        self.respond_with_error = respond_with_error
        self.next_handler = next_handler

    def __call__(self, *args, **kwargs):
        if not self.custom_check():
            return self.respond_with_error("API check failed", status=403)
        return self.next_handler(*args, **kwargs)

    def custom_check(self):
        request_data = self.get_request_data()

        print("In the middleware module")
        # Custom logic based on the API response
        return True
